# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMathematicalMorphologyPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkGrayscaleMorphologicalOpeningImageFilterPython
else:
    import _itkGrayscaleMorphologicalOpeningImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkMathematicalMorphologyEnumsPython
import itk.pyBasePython
import itk.itkFlatStructuringElementPython
import itk.itkImagePython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkPointPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkNeighborhoodPython
import itk.itkBoxImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_New():
    return itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2.New()

class itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterIF2IF2SE2):
    r"""Proxy of C++ itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalOpeningImageFilterPython.delete_itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2

        Create a new object of the class itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2 in _itkGrayscaleMorphologicalOpeningImageFilterPython:
_itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2_swigregister(itkGrayscaleMorphologicalOpeningImageFilterIF2IF2SE2)

def itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_New():
    return itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3.New()

class itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterIF3IF3SE3):
    r"""Proxy of C++ itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalOpeningImageFilterPython.delete_itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3

        Create a new object of the class itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3 in _itkGrayscaleMorphologicalOpeningImageFilterPython:
_itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3_swigregister(itkGrayscaleMorphologicalOpeningImageFilterIF3IF3SE3)

def itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_New():
    return itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2.New()

class itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterISS2ISS2SE2):
    r"""Proxy of C++ itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalOpeningImageFilterPython.delete_itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2

        Create a new object of the class itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2 in _itkGrayscaleMorphologicalOpeningImageFilterPython:
_itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2_swigregister(itkGrayscaleMorphologicalOpeningImageFilterISS2ISS2SE2)

def itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_New():
    return itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3.New()

class itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterISS3ISS3SE3):
    r"""Proxy of C++ itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalOpeningImageFilterPython.delete_itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3

        Create a new object of the class itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3 in _itkGrayscaleMorphologicalOpeningImageFilterPython:
_itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3_swigregister(itkGrayscaleMorphologicalOpeningImageFilterISS3ISS3SE3)

def itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_New():
    return itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2.New()

class itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterIUC2IUC2SE2):
    r"""Proxy of C++ itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalOpeningImageFilterPython.delete_itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2

        Create a new object of the class itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2 in _itkGrayscaleMorphologicalOpeningImageFilterPython:
_itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2_swigregister(itkGrayscaleMorphologicalOpeningImageFilterIUC2IUC2SE2)

def itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_New():
    return itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3.New()

class itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterIUC3IUC3SE3):
    r"""Proxy of C++ itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_Pointer"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalOpeningImageFilterPython.delete_itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3

        Create a new object of the class itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3 in _itkGrayscaleMorphologicalOpeningImageFilterPython:
_itkGrayscaleMorphologicalOpeningImageFilterPython.itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3_swigregister(itkGrayscaleMorphologicalOpeningImageFilterIUC3IUC3SE3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def grayscale_morphological_opening_image_filter(*args: itkt.ImageLike,  kernel: Union[itkt.FlatStructuringElement, itkt.FlatStructuringElement]=..., algorithm=..., safe_border: bool=..., radius: Union[int, Sequence[int], Sequence[int], int]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for GrayscaleMorphologicalOpeningImageFilter"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'algorithm':algorithm,'safe_border':safe_border,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.GrayscaleMorphologicalOpeningImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def grayscale_morphological_opening_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMathematicalMorphology.GrayscaleMorphologicalOpeningImageFilter
    grayscale_morphological_opening_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    grayscale_morphological_opening_image_filter.__doc__ = filter_object.__doc__



